/*
 * 
 * Ejemplo para comunicarse con una cmara que use el ocx DVM_IPCam2.ocx, como la zaapa ciprw
 * 
 * Oscar Rodrguez
 * oscarrp@gmail.com
 * 
 * Puede usar este cdigo libremente sin restricciones.
 * 
 */
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace CamaraIPZaapa
{
    public partial class Form1 : Form
    {
        // Declaramos las constantes que usa el ocx
        private const short PRI_REFUSE = 0;
        private const short PRI_VISITOR = 1;
        private const short PRI_OPERATOR = 2;
        private const short PRI_ADMINISTRATOR = 3;

        private const short R320_240 = 8;
        private const short R640_480 = 32;

        private const short OK = 0;
        private const short ERROR_CONNECT = -1;
        private const short ERROR_SOCKET = -2;
        private const short ERROR_TIMEOUT = -3;
        private const short ERROR_VERSION = -4;
        private const short ERROR_CANCEL = -5;
        private const short ERROR_CLOSED = -6;
        private const short ERROR_UNKNOWN = -7;
        private const short ERROR_FILE = -8;
        private const short ERROR_PARAM = -9;
        private const short ERROR_THREAD = -10;
        private const short ERROR_STATUS = -11;
        private const short ERROR_ID = -12;
        private const short FAIL_USER = 1;
        private const short FAIL_MAXCONNS = 2;
        private const short FAIL_VERSION = 3;
        private const short FAIL_ID = 4;
        private const short FAIL_PWD = 5;
        private const short FAIL_PRI = 6;

        private const short PTZ_STOP = 1;
        private const short TILT_UP = 0;
        private const short TILT_DOWN = 2;
        private const short PAN_LEFT = 4;
        private const short PAN_RIGHT = 6;
        private const short PTZ_LEFT_UP = 90;
        private const short PTZ_RIGHT_UP = 91;
        private const short PTZ_LEFT_DOWN = 92;
        private const short PTZ_RIGHT_DOWN = 93;
        private const short PTZ_CENTER = 25;
        private const short PTZ_VPATROL = 26;
        private const short PTZ_VPATROL_STOP = 27;
        private const short PTZ_HPATROL = 28;
        private const short PTZ_HPATROL_STOP = 29;
        private const short IO_ON = 94;
        private const short IO_OFF = 95;

        // evento que comprueba si la conexin fue exitosa
        private void axDVM_IPCam21_OnMonitorConnectResult(object sender, AxDVM_IPCAM2Lib._DDVM_IPCam2Events_OnMonitorConnectResultEvent e)
        {
            if (e.result == OK)
            {
                axDVM_IPCam21.PlayVideo();
            }
            else
            {
                MessageBox.Show("No se pudo conectar");
            }
        }

        // evento que indica si ya se estan recibiendo imagenes
        private void axDVM_IPCam21_OnPlayVideoResult(object sender, AxDVM_IPCAM2Lib._DDVM_IPCam2Events_OnPlayVideoResultEvent e)
        {
            if (e.result == OK)
            {
                // se activan los botones
                btnArriba.Enabled = true;
                btnAbajo.Enabled = true;
                btnIzquierda.Enabled = true;
                btnDerecha.Enabled = true;
                btnFoto.Enabled = true;
            }
            else
            {
                MessageBox.Show("No se pudo mostrar el video");
            }
        }

        public Form1()
        {
            InitializeComponent();
        }

        // evento para validarse con la cmara si se pulsa el boton conectar
        private void btnConectar_Click(object sender, EventArgs e)
        {
            axDVM_IPCam21.MonitorConnect(txtHost.Text,
                short.Parse(txtPuerto.Text),
                txtUsuario.Text,
                txtClave.Text);
        }

        // evento que se desconecta limpiamente de la cmara si se cierra la aplicacin
        private void Form1_FormClosing(object sender, FormClosingEventArgs e)
        {
            if (axDVM_IPCam21.MonitorStatus == 2)
            {
                axDVM_IPCam21.StopVideo();
                axDVM_IPCam21.StopRecord();
                axDVM_IPCam21.MonitorDisconnect();
            }
        }

        // evento para guardar una foto de lo que se est visualizando
        private void btnFoto_Click(object sender, EventArgs e)
        {
            saveFileDialog1.Filter = "JPG|*.jpg";
            if (saveFileDialog1.ShowDialog() == DialogResult.OK)
            {
                axDVM_IPCam21.Photo2(saveFileDialog1.FileName);
            }
        }

        // evento para empezar el movimiento hacia arriba
        private void btnArriba_MouseDown(object sender, MouseEventArgs e)
        {
            axDVM_IPCam21.DecoderControl(TILT_UP);
        }

        // evento para parar el movimiento de la cmara
        private void btnArriba_MouseUp(object sender, MouseEventArgs e)
        {
            axDVM_IPCam21.DecoderControl(PTZ_STOP);
        }

        // evento para empezar el movimiento hacia abajo
        private void btnAbajo_MouseDown(object sender, MouseEventArgs e)
        {
            axDVM_IPCam21.DecoderControl(TILT_DOWN);
        }

        // evento para parar el movimiento de la cmara
        private void btnAbajo_MouseUp(object sender, MouseEventArgs e)
        {
            axDVM_IPCam21.DecoderControl(PTZ_STOP);
        }

        // evento para empezar el movimiento hacia la izquierda
        private void btnIzquierda_MouseDown(object sender, MouseEventArgs e)
        {
            axDVM_IPCam21.DecoderControl(PAN_LEFT);
        }

        // evento para parar el movimiento de la cmara
        private void btnIzquierda_MouseUp(object sender, MouseEventArgs e)
        {
            axDVM_IPCam21.DecoderControl(PTZ_STOP);
        }

        // evento para empezar el movimiento hacia la derecha
        private void btnDerecha_MouseDown(object sender, MouseEventArgs e)
        {
            axDVM_IPCam21.DecoderControl(PAN_RIGHT);
        }

        // evento para parar el movimiento de la cmara
        private void btnDerecha_MouseUp(object sender, MouseEventArgs e)
        {
            axDVM_IPCam21.DecoderControl(PTZ_STOP);
        }


    }
}